@@ -9,8 +9,8 @@ from uno import createUnoStruct
 from unogenerator.reusing.listdict_functions import listdict_min
 from time import sleep
 
-__version__ = '0.14.0'
-__versiondatetime__=datetime(2021, 11, 21, 19, 27)
+__version__ = '0.15.0'
+__versiondatetime__=datetime(2021, 11, 24, 12, 17)
 __versiondate__=__versiondatetime__.date()
 
 try:
@@ -476,6 +476,14 @@ def get_from_process_numinstances_and_firstport():
         print(_("I couldn't detect unogenerator instances"))
     return len(ld), listdict_min(ld,"port")
    
+def is_formula(s):
+    if s is None:
+        return False
+    s=str(s)
+    if s.startswith("=") or s.startswith("+"):
+        return True
+    return False
+   
 def red(s):
     return Style.BRIGHT + Fore.RED + str(s) + Style.RESET_ALL
 def green(s):
